@@ -3,7 +3,7 @@
 /*
  *  File-Roller
  *
- *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003, 2004 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,10 +24,10 @@
 #include <string.h>
 
 #include <gnome.h>
-#include <glade/glade.h>
 
 #include "bookmarks.h"
 #include "file-utils.h"
+#include "fr-stock.h"
 #include "main.h"
 #include "gtk-utils.h"
 #include "window.h"
@@ -35,20 +35,10 @@
 #include "gconf-utils.h"
 
 
-#define GLADE_FILE "file_roller.glade"
-
-
 typedef struct {
 	FRWindow     *window;
-	GladeXML     *gui;
 
 	GtkWidget    *dialog;
-	GtkWidget    *e_extract_to_fileentry;
-	GtkWidget    *e_extract_to_entry;
-
-	GtkWidget    *e_fav_tree_view;
-	GtkWidget    *e_add_fav_button;
-	GtkWidget    *e_remove_fav_button;
 
 	GtkWidget    *e_all_radiobutton;
 	GtkWidget    *e_selected_radiobutton;
@@ -63,7 +53,6 @@ typedef struct {
 	GtkWidget    *e_view_folder_checkbutton;
 
 	gboolean      extract_clicked;
-	GtkTreeModel *fav_model;
 } DialogData;
 
 
@@ -77,35 +66,76 @@ destroy_cb (GtkWidget  *widget,
 		window_batch_mode_stop (data->window);
 	}
 
-        g_object_unref (data->gui);
         g_free (data);
 }
 
 
-/* called when the "ok" button is pressed. */
 static void
-ok_clicked_cb (GtkWidget  *widget, 
-	       DialogData *data)
+show_dialog_help (DialogData *data)
 {
-	char       *extract_to_dir_utf8;
-	char       *extract_to_dir;
+	GError *err;
+
+	err = NULL;  
+	gnome_help_display ("file-roller", "fr-extracting", &err);
+	
+	if (err != NULL) {
+		GtkWidget *dialog;
+		
+		dialog = _gtk_message_dialog_new (GTK_WINDOW (data->dialog),
+						  GTK_DIALOG_DESTROY_WITH_PARENT, 
+						  GTK_STOCK_DIALOG_ERROR,
+						  _("Could not display help"),
+						  err->message,
+						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  NULL);
+		
+		g_signal_connect (G_OBJECT (dialog), "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+		
+		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+		
+		gtk_widget_show (dialog);
+		
+		g_error_free (err);
+	}
+}
+
+
+static int
+file_sel_response_cb (GtkWidget   *w,
+		      int          response,
+		      DialogData  *data)
+{
+	FRWindow   *window = data->window;
 	gboolean    do_not_extract = FALSE;
+	char       *extract_to_dir;
 	gboolean    overwrite;
 	gboolean    skip_newer;
 	gboolean    selected_files;
 	gboolean    pattern_files;
 	gboolean    junk_paths;
 	GList      *file_list;
-	FRWindow   *window = data->window;
 	char       *password;
 
+	if (response == GTK_RESPONSE_CANCEL) {
+		gtk_widget_destroy (data->dialog);
+		return TRUE;
+	}
+
+	if (response == GTK_RESPONSE_HELP) {
+		show_dialog_help (data);
+		return TRUE;
+	}
+
+	if (response != GTK_RESPONSE_OK) 
+		return FALSE;
+
 	data->extract_clicked = TRUE;
 
 	/* collect extraction options. */
 
-	extract_to_dir_utf8 = gnome_file_entry_get_full_path (GNOME_FILE_ENTRY (data->e_extract_to_fileentry), FALSE);
-	extract_to_dir = g_filename_from_utf8 (extract_to_dir_utf8, -1, 0, 0, 0);
-	g_free (extract_to_dir_utf8);
+	extract_to_dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (data->dialog));
 
 	/* check directory existence. */
 
@@ -149,7 +179,7 @@ ok_clicked_cb (GtkWidget  *widget,
 			gtk_dialog_run (GTK_DIALOG (d));
 			gtk_widget_destroy (GTK_WIDGET (d));
 
-			return;
+			return FALSE;
 		}
 	} 
 	
@@ -166,7 +196,7 @@ ok_clicked_cb (GtkWidget  *widget,
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
 
-		return;
+		return FALSE;
 	}
 
 	/* check extraction directory permissions. */
@@ -193,7 +223,7 @@ ok_clicked_cb (GtkWidget  *widget,
 
 		g_free (extract_to_dir);
 
-		return;
+		return FALSE;
 	}
 
 	window_set_extract_default_dir (window, extract_to_dir);
@@ -226,8 +256,10 @@ ok_clicked_cb (GtkWidget  *widget,
 	/* create the file list. */
 
 	file_list = NULL;
+
 	if (selected_files) 
 		file_list = window_get_file_list_selection (window, TRUE, NULL);
+
 	else if (pattern_files) {
 		const char *pattern;
 		pattern = gtk_entry_get_text (GTK_ENTRY (data->e_files_entry));
@@ -236,7 +268,7 @@ ok_clicked_cb (GtkWidget  *widget,
 			gtk_widget_destroy (data->dialog);
 			g_free (extract_to_dir);
 			g_free (password);
-			return;
+			return FALSE;
 		}
 	}
 
@@ -263,6 +295,8 @@ ok_clicked_cb (GtkWidget  *widget,
 	path_list_free (file_list);
 	g_free (extract_to_dir);
 	g_free (password);
+
+	return TRUE;
 }
 
 
@@ -275,19 +309,6 @@ files_entry_changed_cb (GtkWidget  *widget,
 }
 
 
-static void
-path_entry_changed (GtkWidget  *widget, 
-		    DialogData *data)
-{
-	const char *path;
-	gboolean    can_add;
-
-	path = gtk_entry_get_text (GTK_ENTRY (data->e_extract_to_entry));
-	can_add = g_utf8_strlen (path, -1) > 0;
-	gtk_widget_set_sensitive (data->e_add_fav_button, can_add);
-}
-
-
 static void
 overwrite_toggled_cb (GtkToggleButton *button,
 		      DialogData      *data)
@@ -299,227 +320,180 @@ overwrite_toggled_cb (GtkToggleButton *button,
 
 
 static void
-update_bookmark_list (DialogData *data)
-{
-	Bookmarks   *bookmarks;
-	GtkTreeIter  iter;
-	GList       *scan;
-
-	if (GTK_WIDGET_REALIZED (data->e_fav_tree_view)) 
-		gtk_tree_view_scroll_to_point (GTK_TREE_VIEW (data->e_fav_tree_view), 0, 0);
-
-	gtk_list_store_clear (GTK_LIST_STORE (data->fav_model));
-	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (data->fav_model), 0, GTK_SORT_ASCENDING);
-
-	bookmarks = bookmarks_new (RC_BOOKMARKS_FILE);
-	bookmarks_load_from_disk (bookmarks);
-
-	for (scan = bookmarks->list; scan; scan = scan->next) {
-		char *utf8_name;
-
-		gtk_list_store_append (GTK_LIST_STORE (data->fav_model),
-				       &iter);
-
-		utf8_name = g_filename_to_utf8 (scan->data, -1, 0, 0, 0);
-		gtk_list_store_set (GTK_LIST_STORE (data->fav_model), &iter,
-				    0, utf8_name,
-				    -1);
-		g_free (utf8_name);
-	}
-
-	bookmarks_free (bookmarks);
-}
-
-
-/* called when the "add to favorites" button is pressed. */
-static void
-add_fav_cb (GtkWidget  *widget, 
-	    DialogData *data)
-{
-	Bookmarks  *bookmarks;
-	char       *path;
-
-	path = _gtk_entry_get_filename_text (GTK_ENTRY (data->e_extract_to_entry));
-	if (path == NULL) 
-		return;
-
-	if ((path[strlen (path) - 1] == '/') && (strcmp (path, "/") != 0))
-		path[strlen (path) - 1] = 0;
-
-	bookmarks = bookmarks_new (RC_BOOKMARKS_FILE);
-	bookmarks_load_from_disk (bookmarks);
-	bookmarks_add (bookmarks, path);
-	bookmarks_write_to_disk (bookmarks);
-	bookmarks_free (bookmarks);
-
-	g_free (path);
-
-	update_bookmark_list (data);
-}
-
-
-/* called when the "remove favorite" button is pressed. */
-static void
-remove_fav_cb (GtkWidget  *widget, 
-	       DialogData *data)
-{
-	GtkTreeIter  iter;
-	Bookmarks   *bookmarks;
-	gchar       *path;
-
-	bookmarks = bookmarks_new (RC_BOOKMARKS_FILE);
-	bookmarks_load_from_disk (bookmarks);
-
-	if (! gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (data->e_fav_tree_view)), NULL, &iter))
-		return;
-
-	gtk_tree_model_get (GTK_TREE_MODEL (data->fav_model), &iter,
-                            0, &path,
-                            -1);
-	bookmarks_remove (bookmarks, path);
-	g_free (path);
-
-	bookmarks_write_to_disk (bookmarks);
-	bookmarks_free (bookmarks);
-	update_bookmark_list (data);
-}
-
-
-static gboolean
-fav_item_activated_cb (GtkTreeView       *tree_view, 
-		       GtkTreePath       *path, 
-		       GtkTreeViewColumn *column, 
-		       gpointer           callback_data)
-
-{
-        DialogData  *data = callback_data;
-	GtkTreeIter  iter;
-	gchar       *dir;
-
-	if (! gtk_tree_model_get_iter (data->fav_model, &iter, path)) 
-		return FALSE;
-
-	gtk_tree_model_get (data->fav_model, &iter,
-			    0, &dir,
-			    -1);
-	gtk_entry_set_text (GTK_ENTRY (data->e_extract_to_entry), dir);
-	g_free (dir);
-
-	return FALSE;
-}
-
-
-/* called when the "help" button is clicked. */
-static void
-help_clicked_cb (GtkWidget  *widget, 
-		 DialogData *data)
-{
-	GError *err;
-
-	err = NULL;  
-	gnome_help_display ("file-roller", "fr-extracting", &err);
-	
-	if (err != NULL) {
-		GtkWidget *dialog;
-		
-		dialog = _gtk_message_dialog_new (GTK_WINDOW (data->dialog),
-						  GTK_DIALOG_DESTROY_WITH_PARENT, 
-						  GTK_STOCK_DIALOG_ERROR,
-						  _("Could not display help"),
-						  err->message,
-						  GTK_STOCK_OK, GTK_RESPONSE_OK,
-						  NULL);
-		
-		g_signal_connect (G_OBJECT (dialog), "response",
-				  G_CALLBACK (gtk_widget_destroy),
-				  NULL);
-		
-		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-		
-		gtk_widget_show (dialog);
-		
-		g_error_free (err);
-	}
-}
-
-
-static void
-set_bold_label (GladeXML   *gui,
-		const char *widget_name,
+set_bold_label (GtkWidget  *label,
 		const char *label_txt)
 {
-	GtkWidget *label;
-	char      *bold_label;
+	char *bold_label;
 
-	label = glade_xml_get_widget (gui, widget_name);
 	bold_label = g_strconcat ("<b>", label_txt, "</b>", NULL);
 	gtk_label_set_markup (GTK_LABEL (label), bold_label);
 	g_free (bold_label);
 }
 
 
+static GtkWidget *
+create_extra_widget (DialogData *data)
+{
+	GtkWidget *vbox1;
+	GtkWidget *hbox28;
+	GtkWidget *vbox19;
+	GtkWidget *e_files_label;
+	GtkWidget *hbox29;
+	GtkWidget *label47;
+	GtkWidget *table1;
+	GSList *e_files_radiobutton_group = NULL;
+	GtkWidget *vbox20;
+	GtkWidget *e_actions_label;
+	GtkWidget *hbox30;
+	GtkWidget *label48;
+	GtkWidget *vbox15;
+	GtkWidget *label31;
+	GtkTooltips *tooltips;
+	
+	tooltips = gtk_tooltips_new ();
+	
+	vbox1 = gtk_vbox_new (FALSE, 6);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 6);
+
+	hbox28 = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (vbox1), hbox28, TRUE, TRUE, 0);
+
+	vbox19 = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox28), vbox19, TRUE, TRUE, 0);
+
+	e_files_label = gtk_label_new ("");
+	set_bold_label (e_files_label, _("Files"));
+	gtk_box_pack_start (GTK_BOX (vbox19), e_files_label, FALSE, FALSE, 0);
+	gtk_label_set_justify (GTK_LABEL (e_files_label), GTK_JUSTIFY_LEFT);
+	gtk_misc_set_alignment (GTK_MISC (e_files_label), 0, 0.5);
+
+	hbox29 = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox19), hbox29, TRUE, TRUE, 0);
+
+	label47 = gtk_label_new (_("    "));
+	gtk_box_pack_start (GTK_BOX (hbox29), label47, FALSE, FALSE, 0);
+	gtk_label_set_justify (GTK_LABEL (label47), GTK_JUSTIFY_LEFT);
+
+	table1 = gtk_table_new (3, 2, FALSE);
+	gtk_box_pack_start (GTK_BOX (hbox29), table1, TRUE, TRUE, 0);
+	gtk_table_set_row_spacings (GTK_TABLE (table1), 6);
+	gtk_table_set_col_spacings (GTK_TABLE (table1), 6);
+
+	data->e_files_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("_Files:"));
+	gtk_table_attach (GTK_TABLE (table1), data->e_files_radiobutton, 0, 1, 2, 3,
+			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
+	gtk_radio_button_set_group (GTK_RADIO_BUTTON (data->e_files_radiobutton), e_files_radiobutton_group);
+	e_files_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (data->e_files_radiobutton));
+
+	data->e_files_entry = gtk_entry_new ();
+	gtk_table_attach (GTK_TABLE (table1), data->e_files_entry, 1, 2, 2, 3,
+			  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
+	gtk_tooltips_set_tip (tooltips, data->e_files_entry, _("example: *.txt; *.doc"), NULL);
+	gtk_entry_set_activates_default (GTK_ENTRY (data->e_files_entry), TRUE);
+	
+	data->e_all_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("_All files"));
+	gtk_table_attach (GTK_TABLE (table1), data->e_all_radiobutton, 0, 2, 0, 1,
+			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
+	gtk_radio_button_set_group (GTK_RADIO_BUTTON (data->e_all_radiobutton), e_files_radiobutton_group);
+	e_files_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (data->e_all_radiobutton));
+	
+	data->e_selected_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("_Selected files"));
+	gtk_table_attach (GTK_TABLE (table1), data->e_selected_radiobutton, 0, 2, 1, 2,
+			  (GtkAttachOptions) (GTK_FILL),
+			  (GtkAttachOptions) (0), 0, 0);
+	gtk_radio_button_set_group (GTK_RADIO_BUTTON (data->e_selected_radiobutton), e_files_radiobutton_group);
+	e_files_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (data->e_selected_radiobutton));
+	
+	vbox20 = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox28), vbox20, TRUE, TRUE, 0);
+
+	e_actions_label = gtk_label_new ("");
+	set_bold_label (e_actions_label, _("Actions"));
+	gtk_box_pack_start (GTK_BOX (vbox20), e_actions_label, FALSE, FALSE, 0);
+	gtk_label_set_use_markup (GTK_LABEL (e_actions_label), TRUE);
+	gtk_label_set_justify (GTK_LABEL (e_actions_label), GTK_JUSTIFY_LEFT);
+	gtk_misc_set_alignment (GTK_MISC (e_actions_label), 0, 0.5);
+
+	hbox30 = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox20), hbox30, TRUE, TRUE, 0);
+
+	label48 = gtk_label_new (_("    "));
+	gtk_box_pack_start (GTK_BOX (hbox30), label48, FALSE, FALSE, 0);
+	gtk_label_set_justify (GTK_LABEL (label48), GTK_JUSTIFY_LEFT);
+
+	vbox15 = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox30), vbox15, TRUE, TRUE, 0);
+	
+	data->e_recreate_dir_checkbutton = gtk_check_button_new_with_mnemonic (_("R_e-create folders"));
+	gtk_box_pack_start (GTK_BOX (vbox15), data->e_recreate_dir_checkbutton, FALSE, FALSE, 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->e_recreate_dir_checkbutton), TRUE);
+
+	data->e_overwrite_checkbutton = gtk_check_button_new_with_mnemonic (_("Over_write existing files"));
+	gtk_box_pack_start (GTK_BOX (vbox15), data->e_overwrite_checkbutton, FALSE, FALSE, 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->e_overwrite_checkbutton), TRUE);
+			
+	data->e_not_newer_checkbutton = gtk_check_button_new_with_mnemonic (_("Do not e_xtract older files"));
+	gtk_box_pack_start (GTK_BOX (vbox15), data->e_not_newer_checkbutton, FALSE, FALSE, 0);
+	
+	data->e_password_hbox = gtk_hbox_new (FALSE, 5);
+	gtk_box_pack_start (GTK_BOX (vbox15), data->e_password_hbox, TRUE, TRUE, 0);
+	
+	label31 = gtk_label_new_with_mnemonic (_("_Password:"));
+	gtk_box_pack_start (GTK_BOX (data->e_password_hbox), label31, FALSE, FALSE, 0);
+	gtk_label_set_justify (GTK_LABEL (label31), GTK_JUSTIFY_LEFT);
+	
+	data->e_password_entry = gtk_entry_new ();
+	gtk_box_pack_start (GTK_BOX (data->e_password_hbox), data->e_password_entry, TRUE, TRUE, 0);
+	gtk_entry_set_activates_default (GTK_ENTRY (data->e_password_entry), TRUE);
+	
+	data->e_view_folder_checkbutton = gtk_check_button_new_with_mnemonic (_("_Open destination folder after extraction"));
+	gtk_box_pack_start (GTK_BOX (vbox1), data->e_view_folder_checkbutton, FALSE, FALSE, 0);
+	
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label31), data->e_password_entry);
+
+	gtk_widget_show_all (vbox1);
+
+	return vbox1;
+}
+
+
 void
 dlg_extract (GtkWidget *widget,
 	     gpointer   callback_data)
 {
-        DialogData        *data;
 	FRWindow          *window = callback_data;
-	GtkWidget         *cancel_button;
-	GtkWidget         *ok_button;
-	GtkWidget         *help_button;
-	gchar             *path;
-	GtkCellRenderer   *renderer;
-	GtkTreeViewColumn *column;
+        DialogData        *data;
+	GtkFileChooser    *file_sel;
 
         data = g_new (DialogData, 1);
 
         data->window = window;
 	data->extract_clicked = FALSE;
 
-	data->gui = glade_xml_new (GLADEDIR "/" GLADE_FILE , NULL, NULL);
-	if (! data->gui) {
-                g_warning ("Could not find " GLADE_FILE "\n");
-                return;
-        }
-
         /* Get the widgets. */
 
-        data->dialog = glade_xml_get_widget (data->gui, "extract_dialog");
-        data->e_extract_to_fileentry = glade_xml_get_widget (data->gui, "e_extract_to_fileentry");
-        data->e_extract_to_entry = glade_xml_get_widget (data->gui, "e_extract_to_entry");
+	data->dialog = gtk_file_chooser_dialog_new (
+				    _("Extract"),
+				    GTK_WINDOW (data->window->app),
+				    GTK_FILE_CHOOSER_ACTION_SAVE,
+				    GTK_STOCK_HELP, GTK_RESPONSE_HELP,
+				    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				    FR_STOCK_EXTRACT, GTK_RESPONSE_OK,
+				    NULL);
+	file_sel = GTK_FILE_CHOOSER (data->dialog);
+	gtk_file_chooser_set_folder_mode (file_sel, TRUE);
+	gtk_file_chooser_set_select_multiple (file_sel, FALSE);
+	gtk_file_chooser_set_local_only (file_sel, TRUE);
 
-	data->e_fav_tree_view = glade_xml_get_widget (data->gui, "e_fav_tree_view");
-	data->e_add_fav_button = glade_xml_get_widget (data->gui, "e_add_fav_button");
-	data->e_remove_fav_button = glade_xml_get_widget (data->gui, "e_remove_fav_button");
-
-        data->e_all_radiobutton = glade_xml_get_widget (data->gui, "e_all_radiobutton");
-        data->e_selected_radiobutton = glade_xml_get_widget (data->gui, "e_selected_radiobutton");
-        data->e_files_radiobutton = glade_xml_get_widget (data->gui, "e_files_radiobutton");
-        data->e_files_entry = glade_xml_get_widget (data->gui, "e_files_entry");
-        data->e_overwrite_checkbutton = glade_xml_get_widget (data->gui, "e_overwrite_checkbutton");
-        data->e_not_newer_checkbutton = glade_xml_get_widget (data->gui, "e_not_newer_checkbutton");
-        data->e_recreate_dir_checkbutton = glade_xml_get_widget (data->gui, "e_recreate_dir_checkbutton");
-        data->e_password_entry = glade_xml_get_widget (data->gui, "e_password_entry");
-        data->e_password_hbox = glade_xml_get_widget (data->gui, "e_password_hbox");
-
-        data->e_view_folder_checkbutton = glade_xml_get_widget (data->gui, "e_view_folder_checkbutton");
-
-	set_bold_label (data->gui, "e_actions_label", _("Actions"));
-	set_bold_label (data->gui, "e_destination_folder_label", _("Destination folder"));
-	set_bold_label (data->gui, "e_files_label", _("Files"));
-
-	ok_button = glade_xml_get_widget (data->gui, "e_ok_button");
-	cancel_button = glade_xml_get_widget (data->gui, "e_cancel_button");
-	help_button = glade_xml_get_widget (data->gui, "e_help_button");
+	gtk_file_chooser_set_extra_widget (file_sel, create_extra_widget (data));
 
 	/* Set widgets data. */
 
-	if (window->extract_default_dir[strlen (window->extract_default_dir) - 1] != '/')
-		path = g_strconcat (window->extract_default_dir, "/", NULL);
-	else
-		path = g_strdup (window->extract_default_dir);
-	_gtk_entry_set_filename_text (GTK_ENTRY (data->e_extract_to_entry), path);
-	g_free (path);
+	if (window->extract_default_dir != NULL)
+		gtk_file_chooser_set_current_folder (file_sel, window->extract_default_dir);
 	
 	if (_gtk_count_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (window->list_view))) > 0)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->e_selected_radiobutton), TRUE);
@@ -528,23 +502,6 @@ dlg_extract (GtkWidget *widget,
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->e_all_radiobutton), TRUE);
 	}
 
-	data->fav_model = GTK_TREE_MODEL (gtk_list_store_new (1, G_TYPE_STRING));
-	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (data->fav_model), 0, GTK_SORT_ASCENDING);
-	gtk_tree_view_set_model (GTK_TREE_VIEW (data->e_fav_tree_view),
-				 data->fav_model);
-	g_object_unref (G_OBJECT (data->fav_model));
-
-	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes (_("Bookmarks"),
-							   renderer,
-							   "text", 0,
-							   NULL);
-	gtk_tree_view_column_set_sort_column_id (column, 0);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (data->e_fav_tree_view),
-				     column);
-
-	update_bookmark_list (data);
-
 	if (window->archive->command->propPassword) {
 		gtk_widget_set_sensitive (data->e_password_hbox, TRUE);
 		if (window->password != NULL)
@@ -569,45 +526,21 @@ dlg_extract (GtkWidget *widget,
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
 			  data);
-	g_signal_connect_swapped (G_OBJECT (cancel_button), 
-				  "clicked",
-				  G_CALLBACK (gtk_widget_destroy),
-				  G_OBJECT (data->dialog));
-	g_signal_connect (G_OBJECT (ok_button), 
-			  "clicked",
-			  G_CALLBACK (ok_clicked_cb),
-			  data);
-	g_signal_connect (G_OBJECT (help_button), 
-			  "clicked",
-			  G_CALLBACK (help_clicked_cb),
-			  data);
-	g_signal_connect (G_OBJECT (data->e_add_fav_button), 
-			  "clicked",
-			  G_CALLBACK (add_fav_cb),
-			  data);
-	g_signal_connect (G_OBJECT (data->e_remove_fav_button), 
-			  "clicked",
-			  G_CALLBACK (remove_fav_cb),
-			  data);
-	g_signal_connect (G_OBJECT (data->e_extract_to_entry), 
-			  "changed",
-			  G_CALLBACK (path_entry_changed),
+
+	g_signal_connect (G_OBJECT (data->dialog),
+			  "response",
+			  G_CALLBACK (file_sel_response_cb),
 			  data);
+
 	g_signal_connect (G_OBJECT (data->e_overwrite_checkbutton), 
 			  "toggled",
 			  G_CALLBACK (overwrite_toggled_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->e_fav_tree_view), 
-			  "row_activated",
-			  G_CALLBACK (fav_item_activated_cb), 
-			  data);
 	g_signal_connect (G_OBJECT (data->e_files_entry), 
 			  "changed",
 			  G_CALLBACK (files_entry_changed_cb),
 			  data);
 
-	
-
 	/* Run dialog. */
 
         gtk_window_set_transient_for (GTK_WINDOW (data->dialog), 
