@@ -193,20 +193,19 @@ static void
 add_password_arg (FRCommand     *comm,
 		  const char    *password)
 {
-	fr_process_add_arg (comm->process, "-P");
-
-	if (password != NULL) {
+	if ((password != NULL) && (*password != 0)) {
 		char *arg;
 		char *e_password;
 
+		fr_process_add_arg (comm->process, "-P");
+
 		e_password = escape_str (password, "\"");
 		arg = g_strconcat ("\"", e_password, "\"", NULL);
 		g_free (e_password);
 
 		fr_process_add_arg (comm->process, arg);
 		g_free (arg);
-	} else
-		fr_process_add_arg (comm->process, "\"\"");
+	}
 }
 
 
